import { IAjaxRes } from './utils/ajax';
export interface ITinyOSSOptions {
    accessKeyId: string;
    accessKeySecret: string;
    stsToken?: string;
    bucket?: string;
    endpoint?: string;
    region?: string;
    internal?: boolean;
    secure?: boolean;
    timeout?: number;
    cname?: boolean;
    policy?: string;
    [key: string]: any;
}
export interface IResponseHeaderType {
    'content-type'?: string;
    'content-disposition'?: string;
    'cache-control'?: string;
    [key: string]: any;
}
export declare type THttpMethods = 'GET' | 'POST' | 'DELETE' | 'PUT';
export interface ISignatureUrlOptions {
    expires?: number;
    method?: THttpMethods;
    'Content-Type'?: string;
    process?: string;
    response?: IResponseHeaderType;
    callback?: IObjectCallback;
    [key: string]: any;
}
export interface IObjectCallback {
    url: string;
    host?: string;
    body: string;
    contentType?: string;
    customValue?: Record<string, any>;
    headers?: Record<string, any>;
    [key: string]: any;
}
interface IPutOptions {
    progress?(process: number): void;
    xhrInit?(xhr: XMLHttpRequest, abort: () => void): void;
}
export default class TinyAliOSS {
    constructor(options?: ITinyOSSOptions);
    host: string;
    opts: ITinyOSSOptions;
    put<T>(objectName: string, file: File, options?: IPutOptions): Promise<IAjaxRes<T>>;
    putSymlink<T>(name: string, targetName: string): Promise<IAjaxRes<T>>;
    signatureUrl(objectName: string, options?: ISignatureUrlOptions): string;
}
export {};
