import md5 from 'md5';
import base64js from 'base64-js';
import Sha1 from 'jssha/dist/sha1';
function isDate(obj) {
    return obj && Object.prototype.toString.call(obj) === '[object Date]' && obj.toString !== 'Invalid Date';
}
export function unix(date) {
    var d;
    if (date) {
        d = new Date(date);
    }
    if (!isDate(d)) {
        d = new Date();
    }
    return Math.round(d.getTime() / 1000);
}
export function blobToBuffer(file) {
    return new Promise(function (resolve, reject) {
        var fr = new FileReader();
        fr.onload = function () {
            var result = new Uint8Array(fr.result);
            resolve(result);
        };
        fr.onerror = function () {
            reject(fr.error);
        };
        fr.readAsArrayBuffer(file);
    });
}
export function filterOptions(options) {
    var accessKeyId = options.accessKeyId, accessKeySecret = options.accessKeySecret, bucket = options.bucket, endpoint = options.endpoint;
    if (!accessKeyId) {
        throw new Error('need accessKeyId');
    }
    if (!accessKeySecret) {
        throw new Error('need accessKeySecret');
    }
    if (!bucket && !endpoint) {
        throw new Error('need bucket or endpoint');
    }
}
function hexToBuffer(hex) {
    var arr = [];
    for (var i = 0; i < hex.length; i += 2) {
        arr.push(parseInt(hex[i] + hex[i + 1], 16));
    }
    return Uint8Array.from(arr);
}
export function getContentMd5(buf) {
    // md5 doesn't work for Uint8Array
    var bytes = Array.prototype.slice.call(buf, 0);
    var md5Buf = hexToBuffer(md5(bytes));
    return base64js.fromByteArray(md5Buf);
}
function getCannibalizedOSSHeaders(headers) {
    var result = '';
    var headerNames = Object.keys(headers);
    headerNames = headerNames.map(function (name) { return name.toLowerCase(); });
    headerNames.sort();
    headerNames.forEach(function (name) {
        if (name.indexOf('x-oss-') === 0) {
            result += name + ":" + headers[name] + "\n";
        }
    });
    return result;
}
function getCannibalizedResource(bucket, objectName, parameters) {
    if (bucket === void 0) { bucket = ''; }
    if (objectName === void 0) { objectName = ''; }
    var resourcePath = '';
    if (bucket) {
        resourcePath += "/" + bucket;
    }
    if (objectName) {
        if (objectName.charAt(0) !== '/') {
            resourcePath += '/';
        }
        resourcePath += objectName;
    }
    var cannibalizedResource = "" + resourcePath;
    var separatorString = '?';
    if (parameters) {
        var compareFunc = function (entry1, entry2) {
            if (entry1[0] > entry2[0]) {
                return 1;
            }
            if (entry1[0] < entry2[0]) {
                return -1;
            }
            return 0;
        };
        var processFunc = function (key) {
            cannibalizedResource += separatorString + key;
            if (parameters[key]) {
                cannibalizedResource += "=" + parameters[key];
            }
            separatorString = '&';
        };
        Object.keys(parameters).sort(compareFunc).forEach(processFunc);
    }
    return cannibalizedResource;
}
export function getSignature(options) {
    if (options === void 0) { options = {}; }
    var _a = options.type, type = _a === void 0 ? 'header' : _a, _b = options.verb, verb = _b === void 0 ? '' : _b, _c = options.contentMd5, contentMd5 = _c === void 0 ? '' : _c, _d = options.expires, expires = _d === void 0 ? unix() + 3600 : _d, bucket = options.bucket, objectName = options.objectName, accessKeySecret = options.accessKeySecret, _e = options.headers, headers = _e === void 0 ? {} : _e, subResource = options.subResource;
    var date = headers['x-oss-date'] || '';
    var contentType = headers['Content-Type'] || '';
    var data = [verb, contentMd5, contentType];
    if (type === 'header') {
        data.push(date);
    }
    else {
        data.push(expires);
    }
    var cannibalizedOSSHeaders = getCannibalizedOSSHeaders(headers);
    var cannibalizedResource = getCannibalizedResource(bucket, objectName, subResource);
    data.push("" + cannibalizedOSSHeaders + cannibalizedResource);
    var text = data.join('\n');
    var hmac = new Sha1('SHA-1', 'TEXT', { hmacKey: { value: accessKeySecret, format: 'TEXT' } });
    hmac.update(text);
    var hashBuf = hmac.getHash('UINT8ARRAY');
    var signature = base64js.fromByteArray(hashBuf);
    return signature;
}
//# sourceMappingURL=index.js.map